@@ -5,7 +5,9 @@
     skin = JSON.parse(skin.html());
     $(this).attr("data-skin", skin.name);
     var slider = $(this).data("ionRangeSlider");
-    slider.update({skin: skin.name});
+    if (typeof slider !== "undefined") {
+      slider.update({skin: skin.name});
+    }
   });
 
 })();
